@@ -1,17 +1,17 @@
 
 #define HOST_CPU "i386"
 #define HOST_VENDOR "unknown"
-#define HOST_OS "freebsd2.2.1"
+#define HOST_OS "freebsd2.2.6"
 #define HOST_OS_NAME "freebsd2"
-#define HOST_OS_VERSION "2.2.1"
+#define HOST_OS_VERSION "2.2.6"
 #define HOST_ARCH "i386"
-#define HOST_NAME "bmt.cs.columbia.edu"
+#define HOST_NAME "dingo.mcl.cs.columbia.edu"
 #define USER_NAME "ezk"
-#define CONFIG_DATE "Tue Apr 21 14:01:21 EDT 1998"
+#define CONFIG_DATE "Fri Jul 17 06:48:48 EDT 1998"
 #define PACKAGE "am-utils"
-#define VERSION "6.0a16"
+#define VERSION "6.0a17s2"
 #define PACKAGE "am-utils"
-#define VERSION "6.0a16"
+#define VERSION "6.0a17s2"
 #define DEBUG 1
 #define YYTEXT_POINTER 1
 #define HAVE_LIBRPCSVC 1
@@ -220,6 +220,7 @@
 #define HAVE_RESTARTABLE_SYSCALLS 1
 #define HAVE_FIELD_CDFS_ARGS_T_FLAGS 1
 #define HAVE_FIELD_CDFS_ARGS_T_FSPEC 1
+#define HAVE_FIELD_CDFS_ARGS_T_SSECTOR 1
 #define HAVE_FIELD_PCFS_ARGS_T_FSPEC 1
 #define HAVE_FIELD_PCFS_ARGS_T_GID 1
 #define HAVE_FIELD_PCFS_ARGS_T_MASK 1
@@ -230,10 +231,15 @@
 #define HAVE_FIELD_NFS_ARGS_T_SOTYPE 1
 #define HAVE_FIELD_STRUCT_IFREQ_IFR_ADDR 1
 #define HAVE_FIELD_STRUCT_SOCKADDR_SA_LEN 1
+#define HAVE_FGETS 1
 #define HAVE_MAP_FILE 1
+#define HAVE_DBM_OPEN 1
 #define HAVE_MAP_NDBM 1
+#define HAVE_YP_GET_DEFAULT_DOMAIN 1
 #define HAVE_MAP_NIS 1
+#define HAVE_GETPWNAM 1
 #define HAVE_MAP_PASSWD 1
+#define HAVE_OPENDIR 1
 #define HAVE_MAP_UNION 1
 #define HAVE_FS_CDFS 1
 #define HAVE_FS_LOFS 1
@@ -298,3 +304,4 @@
 #define MNT2_NFS_OPT_TIMEO 0x8
 #define MNT2_NFS_OPT_WSIZE 0x2
 #define HIDE_MOUNT_TYPE "nfs"
+#define HAVE_GETMNTINFO 1
